#![allow(clippy::module_inception)]

yazi_macro::mod_flat!(file out r#in);
